@@ -2,7 +2,6 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.postgres.search import SearchVector
 from django.db.models import Prefetch, Q
 from django.utils.timezone import now
-from django.utils.translation import ugettext_lazy as _
 from django_filters import rest_framework as filters
 from rest_framework.exceptions import ValidationError
 
@@ -76,10 +75,6 @@ class ProductFilter(filters.FilterSet):
     """Product filters"""
 
     category = filters.CharFilter(method="by_category")
-    store = filters.CharFilter(
-        method="by_store",
-        help_text=_("store id param to get only the variants in this store"),
-    )
 
     class Meta:
         model = Product
@@ -92,19 +87,6 @@ class ProductFilter(filters.FilterSet):
     def by_category(self, queryset, name, value):
         return queryset.filter(category__name__iexact=value)
 
-    def by_store(self, queryset, name, value):
-        queryset = queryset.filter(
-            product_variants__inventories__store=value
-        ).prefetch_related(
-            Prefetch(
-                "product_variants",
-                queryset=ProductVariant.objects.filter(
-                    inventories__store=value
-                ).distinct(),
-            )
-        )
-        return queryset
-
 
 class VariantFilter(filters.FilterSet):
     """Variant filters"""
@@ -154,7 +136,20 @@ class CategoryFilter(filters.FilterSet):
         )
 
     def by_type(self, queryset, name, value):
-        return queryset.filter(subcategories__products__type=value)
+        return (
+            queryset.filter(
+                subcategories__products__type=value,
+            )
+            .prefetch_related(
+                Prefetch(
+                    "subcategories__products",
+                    queryset=Product.objects.filter(
+                        is_active=True,
+                    ).distinct(),
+                ),
+            )
+            .distinct()
+        )
 
 
 class OrderFilter(filters.FilterSet):
