@@ -130,7 +130,6 @@ class OrderItemSerializer(InventoryValidationMixin, serializers.ModelSerializer)
             "total_amount",
             "preparation_time",
             "notes",
-            "extra_infos",
             "attribute_choices",
             "attribute_choices_total_amount",
         )
@@ -238,10 +237,10 @@ class OrderSerializer(serializers.ModelSerializer):
             if len(errors) > 0:
                 raise serializers.ValidationError(errors)
             try:
-                variant = ProductVariant.objects.get(id=gift_details["digital_product"])
+                product = Product.objects.get(id=gift_details["digital_product"])
             except ObjectDoesNotExist:
                 raise serializers.ValidationError(_("Digital product does not exist!"))
-            if variant.product.type == Product.ProductTypes.PHYSICAL:
+            if product.type == Product.ProductTypes.PHYSICAL:
                 raise serializers.ValidationError(
                     _("You must not fill extra infos for physical products.")
                 )
@@ -334,7 +333,7 @@ class OrderSerializer(serializers.ModelSerializer):
                 orders=orders,
             )
         except ValidationError as err:
-            raise serializers.ValidationError(_(str(err)))
+            raise serializers.ValidationError(detail=err.message_dict)
         except TapException as err:
             raise serializers.ValidationError({"tap": _(str(err))})
         return {
@@ -349,13 +348,7 @@ class OrderSerializer(serializers.ModelSerializer):
         gift_details = validated_data["extra_infos"].get("gift_details", None)
         if gift_details:
             amount = gift_details["price"]
-            variant = ProductVariant.objects.get(id=gift_details["digital_product"])
             order = Order.objects.create(customer=user, **validated_data)
-            order_item = OrderItem.objects.create(
-                order=order,
-                product_variant=variant,
-                quantity=1,
-            )
             orders.append(order)
         else:
             cart = user.cart
@@ -396,6 +389,7 @@ class CreateOrderResponseSerializer(serializers.Serializer):
 
                     """,
     )
+    car_id = serializers.IntegerField(required=False)
 
     # write only fields
     shipping_method = serializers.IntegerField(write_only=True, required=False)
@@ -435,7 +429,7 @@ class ProductAttributeSerializer(serializers.ModelSerializer):
 class ProductVariantSerializer(serializers.ModelSerializer):
     product_attributes = ProductAttributeSerializer(many=True)
     is_primary = serializers.SerializerMethodField()
-    active_inventories = serializers.SerializerMethodField()
+    inventory = serializers.SerializerMethodField()
 
     class Meta:
         model = ProductVariant
@@ -445,7 +439,7 @@ class ProductVariantSerializer(serializers.ModelSerializer):
             "sku",
             "product_attributes",
             "is_primary",
-            "active_inventories",
+            "inventory",
             "image",
             "image_thumbnail_medium",
         )
@@ -454,16 +448,22 @@ class ProductVariantSerializer(serializers.ModelSerializer):
     def get_is_primary(self, obj):
         return True if obj.inventories.filter(is_primary=True).exists() else False
 
-    def get_active_inventories(self, obj):
-        qs = obj.inventories.filter(is_active=True)
-        if qs.exists():
-            return qs.values("price", "store", "discount_percent")
+    def get_inventory(self, obj):
+        inventory = None
+        if self.context.get("view"):
+            if self.context["view"].kwargs.get("store_pk"):
+                store_pk = self.context["view"].kwargs["store_pk"]
+                qs = obj.inventories.filter(store=store_pk)
+                if qs.exists():
+                    inventory = qs.values("price", "discount_percent", "quantity")[0]
+        return inventory
 
 
 class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
     image = serializers.SerializerMethodField()
     inventory_quantity = serializers.SerializerMethodField()
     is_uncountable = serializers.SerializerMethodField()
+    is_available_in_store = serializers.SerializerMethodField()
     product_id = serializers.SerializerMethodField()
 
     class Meta:
@@ -483,6 +483,7 @@ class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
             "image",
             "inventory_quantity",
             "is_uncountable",
+            "is_available_in_store",
         )
         extra_kwargs = {
             "store": {
@@ -490,6 +491,9 @@ class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
             },
         }
 
+    def get_is_available_in_store(self, obj):
+        return True if obj.inventory else False
+
     def get_product_id(self, obj):
         return obj.product_variant.product.id
 
@@ -841,9 +845,11 @@ class StoreSerializer(FavoriteMixin, serializers.ModelSerializer):
 
     def get_in_range_delivery(self, obj):
         user_location = self.context["request"].query_params.get("point")
-        in_range_method = obj.shipping_methods.filter(
-            type=ShippingMethod.ShippingType.DELIVERY
-        ).exists()
+        in_range_method = False
+        for shipping_method in obj.shipping_methods.all():
+            if shipping_method.type == ShippingMethod.ShippingType.DELIVERY:
+                in_range_method = True
+                break
         if not in_range_method:
             return True
         if user_location and obj.poly:
@@ -896,9 +902,7 @@ class StoreSerializer(FavoriteMixin, serializers.ModelSerializer):
             return f"{ds}{unit}"
 
     def get_phone_contacts(self, obj):
-        phone_contacts = obj.phone_contacts.filter(is_active=True).order_by(
-            "-is_default"
-        )
+        phone_contacts = obj.phone_contacts.all()
         return PhoneContactSerializer(phone_contacts, many=True).data
 
     def get_current_day_opening_hours(self, obj):
@@ -943,6 +947,7 @@ class TaxSerializer(serializers.ModelSerializer):
             "rate",
             "name",
             "value",
+            "country",
         )
 
 
@@ -1217,3 +1222,58 @@ class WalletTransactionSerializer(serializers.ModelSerializer):
             "created_at",
             "wallet",
         ]
+
+
+class ReorderSerializer(serializers.Serializer):
+    force_cart = serializers.BooleanField(default=False)
+
+    def validate(self, attrs):
+        attrs = super().validate(attrs)
+        order = self.context["view"].get_object()
+        cart = self.context["request"].user.cart
+        stores = Store.objects.filter(store_items__cart=cart).distinct()
+        if attrs["force_cart"]:
+            cart.items.all().delete()
+        elif stores.exists():
+            if stores[0] != order.store or stores.count() > 1:
+                raise ValidationError(
+                    _("Your cart contains items from different store")
+                )
+        return attrs
+
+
+class OrderDataSerializer(serializers.ModelSerializer):
+    """
+    This class takes an Order object and returns a dictionary of initialization data
+    """
+
+    store_name = serializers.SerializerMethodField()
+    customer_email = serializers.SerializerMethodField()
+    payment_method_name = serializers.SerializerMethodField()
+    shipping_address = serializers.SerializerMethodField()
+    shipping_method_name = serializers.SerializerMethodField()
+
+    class Meta:
+        model = Order
+        fields = (
+            "store_name",
+            "customer_email",
+            "payment_method_name",
+            "shipping_method_name",
+            "shipping_address",
+        )
+
+    def get_store_name(self, obj):
+        return obj.store.name if obj.store else None
+
+    def get_customer_email(self, obj):
+        return obj.customer.email if obj.customer else None
+
+    def get_payment_method_name(self, obj):
+        return obj.payment_method.name if obj.payment_method else None
+
+    def get_shipping_address(self, obj):
+        return obj.shipping_address.address_line if obj.shipping_address else None
+
+    def get_shipping_method_name(self, obj):
+        return obj.shipping_method.name if obj.shipping_method else None
