@@ -11,6 +11,7 @@ from ob_dj_store.apis.stores.views import (
     OrderView,
     PaymentMethodViewSet,
     ProductView,
+    ReorderViewSet,
     ShippingMethodViewSet,
     StoreView,
     TaxViewSet,
@@ -40,6 +41,7 @@ router.register(r"cart-item", CartItemView, basename="cart-item")
 router.register(r"favorite", FavoriteViewSet, basename="favorite")
 router.register(r"wallet", WalletViewSet, basename="wallet")
 router.register(r"payment-method", PaymentMethodViewSet, basename="payment-method")
+router.register(r"order", ReorderViewSet, basename="re-order")
 urlpatterns = [
     path(r"", include(router.urls)),
     path(r"", include(stores_router.urls)),
