@@ -3,7 +3,7 @@ import typing
 
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
-from django.db.models import Prefetch
+from django.db.models import Max, Prefetch
 from django.http import Http404
 from django.shortcuts import get_object_or_404
 from django.utils.decorators import method_decorator
@@ -44,6 +44,7 @@ from ob_dj_store.apis.stores.rest.serializers.serializers import (
     ProductListSerializer,
     ProductSerializer,
     ProductVariantSerializer,
+    ReorderSerializer,
     ShippingMethodSerializer,
     StoreSerializer,
     TaxSerializer,
@@ -62,6 +63,7 @@ from ob_dj_store.core.stores.models import (
     Order,
     Payment,
     PaymentMethod,
+    PhoneContact,
     Product,
     ProductVariant,
     ShippingMethod,
@@ -99,8 +101,20 @@ class StoreView(
         return super(StoreView, self).get_permissions()
 
     def get_queryset(self):
-        queryset = super().get_queryset()
-        queryset = queryset.prefetch_related("opening_hours")
+        queryset = (
+            super()
+            .get_queryset()
+            .prefetch_related(
+                "shipping_methods",
+                "opening_hours",
+                Prefetch(
+                    "phone_contacts",
+                    queryset=PhoneContact.objects.filter(is_active=True).order_by(
+                        "-is_default"
+                    ),
+                ),
+            )
+        )
         if self.action == "favorites":
             favorite_store_ids = Favorite.objects.favorites_for_model(
                 Store, self.request.user
@@ -109,22 +123,23 @@ class StoreView(
         # stores that the user has recently ordered from
         if self.action == "recently_ordered_from":
             queryset = (
-                queryset.prefetch_related(
-                    Prefetch(
-                        "orders",
-                        queryset=Order.objects.filter(
-                            customer=self.request.user, status__in=["PAID", "DELIVERED"]
-                        ),
-                    )
-                )
-                .filter(
+                queryset.filter(
                     orders__customer=self.request.user,
                     orders__status__in=[
                         "PAID",
                         "DELIVERED",
                     ],
                 )
-                .order_by("-orders__created_at")
+                .annotate(latest_order_date=Max("orders__created_at"))
+                .prefetch_related(
+                    Prefetch(
+                        "orders",
+                        queryset=Order.objects.filter(
+                            customer=self.request.user, status__in=["PAID", "DELIVERED"]
+                        ).distinct(),
+                    )
+                )
+                .order_by("-latest_order_date")
                 .distinct()
             )
         return prefetch(queryset, self.serializer_class)
@@ -226,7 +241,7 @@ class StoreView(
             product_variants__inventories__store=store,
             category__isnull=False,
             is_active=True,
-        )
+        ).distinct()
         data = {
             "favorites_count": favorites_count,
             "menu_count": menu.count(),
@@ -259,6 +274,7 @@ class StoreView(
                     "DELIVERED",
                 ],
             )
+            .distinct()
             .count()
         )
         nearby_count = super().get_queryset().count()
@@ -288,6 +304,15 @@ class CartView(
 
     @swagger_auto_schema(
         operation_summary="Retrieve Customer Cart",
+        manual_parameters=[
+            openapi.Parameter(
+                "store",
+                in_=openapi.IN_QUERY,
+                description="store id",
+                type=openapi.TYPE_INTEGER,
+                required=True,
+            )
+        ],
         operation_description="""
             Retrieve the current customer's cart /store/cart/me
         """,
@@ -296,7 +321,15 @@ class CartView(
         ],
     )
     def retrieve(self, request, *args, **kwargs):
-        return super().retrieve(request, *args, **kwargs)
+        store_id = request.query_params.get("store", None)
+        instance = self.get_object()
+
+        if store_id and not store_settings.DIFFERENT_STORE_ORDERING:
+            store = get_object_or_404(Store, pk=store_id)
+            instance.items.update(store=store)
+
+        serializer = self.get_serializer(instance)
+        return Response(serializer.data)
 
     @swagger_auto_schema(
         operation_summary="Update Customer Cart",
@@ -463,6 +496,24 @@ class OrderView(
             )
         return Response(serializer.data, status=status.HTTP_200_OK)
 
+
+class ReorderViewSet(
+    mixins.CreateModelMixin,
+    viewsets.GenericViewSet,
+):
+    serializer_class = ReorderSerializer
+    permission_classes = [
+        permissions.IsAuthenticated,
+    ]
+    queryset = Order.objects.all()
+    http_method_names = [
+        "post",
+    ]
+
+    def get_queryset(self):
+        queryset = super().get_queryset()
+        return queryset.filter(customer=self.request.user)
+
     @swagger_auto_schema(
         operation_summary="re-order a Customer Order",
         operation_description="""
@@ -475,26 +526,18 @@ class OrderView(
     @action(
         methods=["POST"],
         detail=True,
-        url_path=r"reorder",
+        url_path=r"",
         permission_classes=[
             permissions.IsAuthenticated,
         ],
     )
     def reorder(self, request: Request, *args: typing.Any, **kwargs: typing.Any):
-        order = self.get_object()
-        request.user.cart.fill(order)
         context = self.get_serializer_context()
-        serializer = OrderSerializer(data=request.data, context=context)
-        orders = []
+        serializer = self.get_serializer(data=request.data, context=context)
         serializer.is_valid(raise_exception=True)
-        orders, payment_url = serializer.save().values()
-        orders_data = OrderSerializer(orders, many=True).data
+        request.user.cart.fill(self.get_object())
         return Response(
-            status=status.HTTP_201_CREATED,
-            data={
-                "payment_url": payment_url,
-                "orders": orders_data,
-            },
+            status=status.HTTP_200_OK,
         )
 
 
@@ -535,12 +578,15 @@ class ProductView(
     filterset_class = ProductFilter
     queryset = Product.objects.active()
 
-    def get_permissions(self):
-        if self.action in ["favorites", "favorite"]:
-            return [
-                permissions.IsAuthenticated(),
-            ]
-        return super(ProductView, self).get_permissions()
+    def apply_prefetch(self, queryset):
+        return queryset.prefetch_related(
+            Prefetch(
+                "product_variants",
+                queryset=ProductVariant.objects.filter(
+                    inventories__store__pk=self.kwargs["store_pk"]
+                ).distinct(),
+            ),
+        ).distinct()
 
     def get_queryset(self):
         queryset = super().get_queryset()
@@ -550,7 +596,14 @@ class ProductView(
             ).values_list("object_id", flat=True)
 
             queryset = self.queryset.filter(pk__in=favorite_product_ids)
-        return queryset.distinct()
+        queryset = self.apply_prefetch(queryset)
+        return queryset
+
+    def get_object(self):
+        queryset = super().get_queryset()
+        queryset = self.apply_prefetch(queryset)
+        pk = self.kwargs.get("pk")
+        return get_object_or_404(queryset, pk=pk)
 
     @swagger_auto_schema(
         operation_summary="Retrieve A Product",
@@ -861,6 +914,7 @@ class FavoriteViewSet(
     mixins.CreateModelMixin,
     mixins.DestroyModelMixin,
     mixins.UpdateModelMixin,
+    mixins.RetrieveModelMixin,
     viewsets.GenericViewSet,
 ):
     serializer_class = FavoriteSerializer
@@ -910,6 +964,18 @@ class FavoriteViewSet(
     def list(self, request, *args, **kwargs):
         return super().list(request, *args, **kwargs)
 
+    @swagger_auto_schema(
+        operation_summary="Retreive Item To Favorites",
+        operation_description="""
+            Retreive  Item To Favorites
+        """,
+        tags=[
+            "Favorite",
+        ],
+    )
+    def retrieve(self, request, *args, **kwargs):
+        return super().retrieve(request, *args, **kwargs)
+
     @swagger_auto_schema(
         operation_summary="Add Item To Favorites",
         operation_description="""
@@ -1052,7 +1118,7 @@ class WalletViewSet(
     def transactions(
         self, request: Request, *args: typing.Any, **kwargs: typing.Any
     ) -> Response:
-        queryset = self.get_object().transactions.all()
+        queryset = self.get_object().transactions.all().order_by("-created_at")
         page = self.paginate_queryset(queryset)
         if page is not None:
             serializer = self.get_serializer(page, many=True)
