@@ -107,5 +107,5 @@ class TapPayment(models.Model):
     def mark_transaction(self):
         if self.status == self.Status.CAPTURED:
             self.payment.mark_paid()
-        elif self.status == self.Status.FAILED:
+        else:
             self.payment.mark_failed()
