@@ -1,3 +1,4 @@
+import json
 import logging
 import typing
 
@@ -61,9 +62,12 @@ class PaymentManager(models.Manager):
                 {"order", _("You cannot perform payment without items")}
             )
         try:
-            kwargs["payment_tax"] = Tax.objects.get(is_active=True)
+            if orders[0].store:
+                kwargs["payment_tax"] = Tax.objects.get(
+                    country=orders[0].store.address.country, is_active=True
+                )
         except ObjectDoesNotExist:
-            raise ValidationError(_("Tax object is missing"), code="invalid")
+            raise ValidationError({"tax": _("Tax object is missing")})
         gateway = settings.DEFAULT_PAYMENT_METHOD
         method = kwargs.get("method", None)
         if method:
@@ -82,6 +86,7 @@ class PaymentManager(models.Manager):
             try:
                 wallet = kwargs["user"].wallets.get(currency=currency)
             except ObjectDoesNotExist:
+                instance.mark_failed()
                 raise ValidationError({"wallet": _("Wallet Not Found")})
             WalletTransaction.objects.create(
                 wallet=wallet,
@@ -91,9 +96,12 @@ class PaymentManager(models.Manager):
         elif gateway == settings.GIFT:
             gift_payment_path = getattr(settings, "GIFT_PAYMENT_METHOD_PATH", None)
             payment_funciton = import_gift_payment_function(gift_payment_path)
-            payment_funciton(
-                gift_card=orders[0].extra_infos["gift_card"], payment=instance
+            response = payment_funciton(
+                gift_card_id=orders[0].extra_infos["gift_card"], payment=instance
             )
+            if not response["success"]:
+                instance.mark_failed()
+                raise ValidationError({"gift_card": response["error"]})
         instance.mark_paid()
         return instance
 
@@ -102,9 +110,29 @@ class InventoryManager(ActiveMixin, models.Manager):
     pass
 
 
+class OrderItemManager(models.Manager):
+    def create(self, *args, **kwargs):
+        order_item = super().create(**kwargs)
+        init_data = {
+            "inventory_price": round(float(order_item.inventory.price), 3)
+            if order_item.inventory
+            else 0
+        }
+        order_item.init_data = json.dumps(init_data)
+        order_item.save()
+        return order_item
+
+
 class OrderManager(models.Manager):
     def create(self, *args, **kwargs):
+        from ob_dj_store.apis.stores.rest.serializers.serializers import (
+            OrderDataSerializer,
+        )
+
         order = super().create(**kwargs)
+        serializer = OrderDataSerializer(order)
+        order.init_data = serializer.data
+        order.save()
         return order
 
 
