@@ -26,7 +26,11 @@ from ob_dj_store.core.stores.models._store import (
     ShippingMethod,
     Store,
 )
-from ob_dj_store.core.stores.models._wallet import Wallet, WalletTransaction
+from ob_dj_store.core.stores.models._wallet import (
+    Wallet,
+    WalletMedia,
+    WalletTransaction,
+)
 
 __all__ = [
     "Store",
@@ -60,4 +64,5 @@ __all__ = [
     "WalletTransaction",
     "Wallet",
     "FavoriteExtra",
+    "WalletMedia",
 ]
