@@ -27,19 +27,10 @@ class Cart(models.Model):
 
     @property
     def tax_amount(self) -> Decimal:
-        from ob_dj_store.core.stores.models import Tax
-
-        try:
-            tax = Tax.objects.get(is_active=True)
-        except ObjectDoesNotExist:
-            raise ValidationError(_("Tax object is missing"), code="invalid")
-
-        if not tax:
-            return 0
-        if tax.rate == Tax.Rates.PERCENTAGE:
-            perc = Decimal(self.total_price * tax.value / 100)
-            return perc
-        return tax.value
+        amount = Decimal(
+            sum(map(lambda item: Decimal(item.tax_amount), self.items.all()))
+        )
+        return amount
 
     @property
     def total_price(self) -> Decimal:
@@ -58,7 +49,6 @@ class Cart(models.Model):
     def fill(self, order):
         from ob_dj_store.core.stores.models._cart import CartItem
 
-        self.items.all().delete()
         for item in order.items.all():
             cart_item = CartItem.objects.create(
                 cart=self,
@@ -66,7 +56,6 @@ class Cart(models.Model):
                 store=order.store,
                 notes=item.notes,
                 quantity=item.quantity,
-                extra_infos=item.extra_infos,
             )
             attribute_choices = list(item.attribute_choices.all())
             if len(attribute_choices) > 0:
@@ -105,6 +94,9 @@ class CartItem(models.Model):
     class Meta:
         verbose_name_plural = _("Cart Items")
         verbose_name = _("Cart Item")
+        ordering = [
+            "created_at",
+        ]
 
     @property
     def unit_price(self) -> Decimal:
@@ -115,6 +107,23 @@ class CartItem(models.Model):
         except ObjectDoesNotExist:
             return 0
 
+    @property
+    def tax_amount(self) -> Decimal:
+        from ob_dj_store.core.stores.models import Tax
+
+        if self.store:
+            try:
+                tax = Tax.objects.get(
+                    country=self.store.address.country, is_active=True
+                )
+                if tax.rate == Tax.Rates.PERCENTAGE:
+                    perc = Decimal(self.total_price * tax.value / 100)
+                    return perc
+                return tax.value
+            except ObjectDoesNotExist:
+                pass
+        return 0
+
     @property
     def attribute_choices_total_price(self) -> Decimal:
         total_price = Decimal(0)
