@@ -1,3 +1,4 @@
+import json
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
@@ -7,7 +8,7 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from config import settings
-from ob_dj_store.core.stores.managers import OrderManager
+from ob_dj_store.core.stores.managers import OrderItemManager, OrderManager
 from ob_dj_store.utils.model import DjangoModelCleanMixin
 
 
@@ -37,7 +38,10 @@ class Order(DjangoModelCleanMixin, models.Model):
     #       sales and even if a user deleted orders cannot disappear otherwise will reflect
     #       invalid sales figure; same can be applied for the store field
     customer = models.ForeignKey(
-        get_user_model(), related_name="orders", on_delete=models.CASCADE
+        get_user_model(),
+        related_name="orders",
+        on_delete=models.SET_NULL,
+        null=True,
     )
     store = models.ForeignKey(
         "stores.Store",
@@ -95,6 +99,7 @@ class Order(DjangoModelCleanMixin, models.Model):
 
             """,
     )
+    init_data = models.JSONField(null=True, blank=True)
 
     # TODO: add pick_up_time maybe ?
     # audit fields
@@ -130,6 +135,8 @@ class Order(DjangoModelCleanMixin, models.Model):
     def total_amount(self):
         if self.type_of_order == Order.OrderType.WALLET.value:
             return Decimal(self.extra_infos["amount"])
+        elif self.type_of_order == Order.OrderType.GIFT.value:
+            return Decimal(self.extra_infos["gift_details"]["price"])
         amount = Decimal(
             sum(map(lambda item: Decimal(item.total_amount) or 0, self.items.all()))
         )
@@ -144,12 +151,13 @@ class Order(DjangoModelCleanMixin, models.Model):
 
     @property
     def type_of_order(self):
-        if not self.extra_infos:
-            return self.OrderType.PHYSICAL.value
-        is_wallet = self.extra_infos.get("is_wallet_fill_up")
-        if is_wallet:
-            return self.OrderType.WALLET.value
-        return self.OrderType.GIFT.value
+        if self.extra_infos:
+            if self.extra_infos.get("gift_details", None):
+                return self.OrderType.GIFT.value
+            is_wallet = self.extra_infos.get("is_wallet_fill_up")
+            if is_wallet:
+                return self.OrderType.WALLET.value
+        return self.OrderType.PHYSICAL.value
 
     def save(self, **kwargs):
         if not self.pk and self.shipping_address:
@@ -189,7 +197,9 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
         ],
         help_text=_("quantity of the variant"),
     )
-    extra_infos = models.JSONField(null=True, blank=True)
+    init_data = models.JSONField(null=True, blank=True)
+
+    objects = OrderItemManager()
 
     def __str__(self):
         return f"OrderItem - {self.quantity} {self.product_variant.product.name}{self.product_variant.name}"
@@ -213,7 +223,10 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
                 + self.attribute_choices_total_amount
             ) * self.quantity
         except ObjectDoesNotExist:
-            return 0
+            if self.init_data:
+                init_data = json.loads(self.init_data)
+                return init_data["inventory_price"]
+        return 0
 
     @property
     def preparation_time(self):
@@ -251,6 +264,7 @@ class OrderHistory(DjangoModelCleanMixin, models.Model):
     class Meta:
         verbose_name = _("Order History")
         verbose_name_plural = _("Order Histories")
+        unique_together = (("order", "status"),)
 
     def __str__(self):
         return f"OrderHistory - {self.status}"
