@@ -335,3 +335,16 @@ class ProductMedia(DjangoModelCleanMixin, models.Model):
     @property
     def name(self):
         return f"{self.product.name}_{self.order_value}"
+
+    def save(self, *args, **kwargs):
+        # If the current instance is set as primary, unset any existing primary images for the product
+        if self.is_primary:
+            ProductMedia.objects.filter(product=self.product, is_primary=True).update(
+                is_primary=False
+            )
+        elif not ProductMedia.objects.filter(
+            product=self.product, is_primary=True
+        ).exists():
+            # If there are no primary images for the product, set the current instance as primary
+            self.is_primary = True
+        super(ProductMedia, self).save(*args, **kwargs)
