@@ -6,21 +6,56 @@ from django.conf import settings
 from django.db import models
 from django.db.models.functions import Coalesce
 from django.utils.translation import gettext_lazy as _
-from django_countries.fields import CountryField
 
 from ob_dj_store.core.stores.managers import WalletTransactionManager
-from ob_dj_store.core.stores.utils import get_currency_by_country
+from ob_dj_store.core.stores.models._store import PaymentMethod
+from ob_dj_store.core.stores.utils import validate_currency
+from ob_dj_store.utils.helpers import wallet_media_upload_to
+from ob_dj_store.utils.model import DjangoModelCleanMixin
 
 logger = logging.getLogger(__name__)
 
 
+class WalletMedia(DjangoModelCleanMixin, models.Model):
+    """
+    selection images for wallets.
+    """
+
+    image = models.ImageField(upload_to=wallet_media_upload_to)
+    image_thumbnail_medium = models.ImageField(
+        upload_to="wallets/", null=True, blank=True
+    )
+    is_active = models.BooleanField(default=True)
+
+    # Audit fields
+    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(auto_now=True)
+
+
 class Wallet(models.Model):
     user = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         on_delete=models.CASCADE,
         related_name="wallets",
     )
-    country = CountryField(_("the wallet's country"), null=True, blank=True)
+    name = models.CharField(max_length=200, null=True, blank=True)
+    media_image = models.ForeignKey(
+        WalletMedia,
+        on_delete=models.SET_NULL,
+        null=True,
+        blank=True,
+        related_name="wallets",
+    )
+    currency = models.CharField(
+        max_length=3,
+        default="KWD",
+        validators=[
+            validate_currency,
+        ],
+    )
+
+    class Meta:
+        unique_together = ("user", "currency")
 
     def __str__(self) -> typing.Text:
         return f"Wallet(PK={self.pk})"
@@ -49,10 +84,34 @@ class Wallet(models.Model):
         return query["balance"]
 
     @property
-    def currency(self):
-        if self.country:
-            return get_currency_by_country(self.country.name)
-        return None
+    def image_url(self):
+        if self.media_image:
+            image = self.media_image.image_thumbnail_medium
+            return image.url if image else None
+
+    def top_up_wallet(self, amount: Decimal, payment_method: PaymentMethod):
+        from ob_dj_store.core.stores.models import Order, Payment
+
+        user = self.user
+        order = Order.objects.create(
+            customer=user,
+            payment_method=payment_method,
+            extra_infos={
+                "is_wallet_fill_up": True,
+                "amount": str(amount),
+                "currency": self.currency,
+            },
+        )
+        payment = Payment.objects.create(
+            orders=[
+                order,
+            ],
+            user=user,
+            currency=self.currency,
+            method=payment_method,
+            amount=amount,
+        )
+        return payment.payment_url
 
 
 class WalletTransaction(models.Model):
