@@ -38,10 +38,13 @@ def create_customer_cart_and_wallet_handler(sender, instance, created, **kwargs)
     dispatch_uid="create_order_history_handler",
 )
 def create_order_history_handler(sender, instance, created, **kwargs):
-    OrderHistory.objects.create(
-        order=instance,
-        status=instance.status,
-    )
+    try:
+        OrderHistory.objects.create(
+            order=instance,
+            status=instance.status,
+        )
+    except Exception:
+        pass
 
 
 @receiver(
