@@ -3,13 +3,14 @@ import os
 from io import BytesIO
 
 from django.core.files.uploadedfile import InMemoryUploadedFile
+from django.utils.timezone import now
 from PIL import Image, UnidentifiedImageError
 from pilkit.processors import ResizeToFill
 
 logger = logging.getLogger(__name__)
 
 
-def resize_image(image, dim: dict, size_name: str):
+def resize_image(image, dim: dict, size_name: str, image_name: str = None):
     try:
         img = Image.open(image)
     except UnidentifiedImageError as e:
@@ -31,10 +32,12 @@ def resize_image(image, dim: dict, size_name: str):
         new_img = new_img.convert("RGB")
     new_img.save(output, format=img_format, quality=70)
     output.seek(0)
+    if not image_name:
+        image_name = filename
     new_image = InMemoryUploadedFile(
         output,
         "ImageField",
-        f"{filename}_{size_name}.{img_format.lower()}",
+        f"{image_name}_{int(now().timestamp())}_{size_name}.{img_format.lower()}",
         content_type,
         output.__sizeof__(),
         None,
